==> hibiscus.js-1.2.1.tgz: package/oauth2/oauth2.service.js <==
import { Injectable } from '@angular/core';
import { StorageType, StorageService } from '../storage';
import { OAuth2Config } from './oauth2.config';
var isBlank = function (obj) {
    return obj === null || obj === undefined;
};
var ɵ0 = isBlank;
var OAuth2Service = /** @class */ (function () {
    function OAuth2Service(storage, config) {
        this.storage = storage;
        this.config = config;
        this.STORAGE_POOL_KEY = 'hi-oauth2';
        this.STORAGE_DATA_KEY = 'hi-data';
        this.STORAGE_TOKEN_KEY = 'hi-token';
        this.storageType = isBlank(config.storageType) ?
            StorageType.localStorage : config.storageType;
    }
    OAuth2Service.prototype.setStorageType = function (storageType) {
        this.storageType = storageType;
    };
    OAuth2Service.prototype.set = function (data) {
        this.storage.put({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_DATA_KEY,
            storageType: this.storageType
        }, data);
        this.data = data;
        if (this.data.token) {
            this.setToken(this.data.token);
        }
    };
    OAuth2Service.prototype.get = function () {
        if (this.data) {
            return this.data;
        }
        return this.data = this.storage.get({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_DATA_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.setToken = function (token) {
        this.storage.put({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_TOKEN_KEY,
            storageType: this.storageType
        }, token);
        this.token = token;
    };
    OAuth2Service.prototype.getToken = function () {
        if (this.token) {
            return this.token;
        }
        return this.token = this.storage.get({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_TOKEN_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.remove = function () {
        this.removeToken();
        this.data = null;
        return this.storage.remove({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_DATA_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.removeToken = function () {
        this.token = null;
        return this.storage.remove({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_TOKEN_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.isAuthorized = function () {
        return !!this.get() === false ? !!this.getToken() : true;
    };
    OAuth2Service.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    OAuth2Service.ctorParameters = function () { return [
        { type: StorageService, },
        { type: OAuth2Config, },
    ]; };
    return OAuth2Service;
}());
export { OAuth2Service };
export { ɵ0 };

==> hibiscus.js-1.2.3.tgz: package/oauth2/oauth2.service.js <==
import { Injectable } from '@angular/core';
import { StorageType, StorageService } from '../storage';
import { OAuth2Config } from './oauth2.config';
var isBlank = function (obj) {
    return obj === null || obj === undefined;
};
var ɵ0 = isBlank;
var OAuth2Service = (function () {
    function OAuth2Service(storage, config) {
        this.storage = storage;
        this.config = config;
        this.STORAGE_POOL_KEY = 'hi-oauth2';
        this.STORAGE_DATA_KEY = 'hi-data';
        this.STORAGE_TOKEN_KEY = 'hi-token';
        this.storageType = isBlank(config.storageType) ?
            StorageType.localStorage : config.storageType;
    }
    OAuth2Service.prototype.setStorageType = function (storageType) {
        this.storageType = storageType;
    };
    OAuth2Service.prototype.set = function (data) {
        this.storage.put({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_DATA_KEY,
            storageType: this.storageType
        }, data);
        this.data = data;
        if (this.data.token) {
            this.setToken(this.data.token);
        }
    };
    OAuth2Service.prototype.get = function () {
        if (this.data) {
            return this.data;
        }
        return this.data = this.storage.get({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_DATA_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.setToken = function (token) {
        this.storage.put({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_TOKEN_KEY,
            storageType: this.storageType
        }, token);
        this.token = token;
    };
    OAuth2Service.prototype.getToken = function () {
        if (this.token) {
            return this.token;
        }
        return this.token = this.storage.get({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_TOKEN_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.remove = function () {
        this.removeToken();
        this.data = null;
        return this.storage.remove({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_DATA_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.removeToken = function () {
        this.token = null;
        return this.storage.remove({
            pool: this.STORAGE_POOL_KEY,
            key: this.STORAGE_TOKEN_KEY,
            storageType: this.storageType
        });
    };
    OAuth2Service.prototype.isAuthorized = function () {
        return !!this.get() === false ? !!this.getToken() : true;
    };
    OAuth2Service.decorators = [
        { type: Injectable },
    ];
    OAuth2Service.ctorParameters = function () { return [
        { type: StorageService, },
        { type: OAuth2Config, },
    ]; };
    return OAuth2Service;
}());
export { OAuth2Service };
export { ɵ0 };
